==> sdd.mercadopago2-0.2.1-sources.jar: ar/com/sdd/mercadopago/entity/payment/AddressReceiver.java <==
package ar.com.sdd.mercadopago.entity.payment;

/**
 * Mercado Pago SDK
 * Receiver address class
 * <p>
 * Created by Eduardo Paoletta on 11/9/16.
 */
public class AddressReceiver extends Address {

    private String floor = null;
    private String apartment = null;


    @Override
    public AddressReceiver setZipCode(String zipCode) {
        return (AddressReceiver) super.setZipCode(zipCode);
    }

    @Override
    public AddressReceiver setStreetName(String streetName) {
        return (AddressReceiver) super.setStreetName(streetName);
    }

    @Override
    public AddressReceiver setStreetNumber(Integer streetNumber) {
        return (AddressReceiver) super.setStreetNumber(streetNumber);
    }

    public String getFloor() {
        return floor;
    }

    public AddressReceiver setFloor(String floor) {
        this.floor = floor;
        return this;
    }

    public String getApartment() {
        return apartment;
    }

    public AddressReceiver setApartment(String apartment) {
        this.apartment = apartment;
        return this;
    }


    @Override
    public String toString() {
        return "AddressReceiver ["
                + ((floor != null) ? "floor=" + floor + ", " : "")
                + ((apartment != null) ? "apartment=" + apartment : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;

        AddressReceiver that = (AddressReceiver) o;

        if (floor != null ? !floor.equals(that.floor) : that.floor != null) return false;
        return apartment != null ? apartment.equals(that.apartment) : that.apartment == null;
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + (floor != null ? floor.hashCode() : 0);
        result = 31 * result + (apartment != null ? apartment.hashCode() : 0);
        return result;
    }
}

==> sdd.mercadopago2-0.2.15-sources.jar: ar/com/sdd/mercadopago/entity/payment/AddressReceiver.java <==
package ar.com.sdd.mercadopago.entity.payment;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.PropertyNamingStrategy;
import com.fasterxml.jackson.databind.annotation.JsonNaming;

/**
 * Mercado Pago SDK
 * Receiver address class
 * <p>
 * Created by Eduardo Paoletta on 11/9/16.
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonNaming(PropertyNamingStrategy.SnakeCaseStrategy.class)
public class AddressReceiver extends Address {

    private String floor = null;
    private String apartment = null;


    @Override
    public AddressReceiver setZipCode(String zipCode) {
        return (AddressReceiver) super.setZipCode(zipCode);
    }

    @Override
    public AddressReceiver setStreetName(String streetName) {
        return (AddressReceiver) super.setStreetName(streetName);
    }

    @Override
    public AddressReceiver setStreetNumber(Integer streetNumber) {
        return (AddressReceiver) super.setStreetNumber(streetNumber);
    }

    public String getFloor() {
        return floor;
    }

    public AddressReceiver setFloor(String floor) {
        this.floor = floor;
        return this;
    }

    public String getApartment() {
        return apartment;
    }

    public AddressReceiver setApartment(String apartment) {
        this.apartment = apartment;
        return this;
    }


    @Override
    public String toString() {
        return "AddressReceiver ["
                + ((floor != null) ? "floor=" + floor + ", " : "")
                + ((apartment != null) ? "apartment=" + apartment : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;

        AddressReceiver that = (AddressReceiver) o;

        if (floor != null ? !floor.equals(that.floor) : that.floor != null) return false;
        return apartment != null ? apartment.equals(that.apartment) : that.apartment == null;
    }

    @Override
    public int hashCode() {
        int result = super.hashCode();
        result = 31 * result + (floor != null ? floor.hashCode() : 0);
        result = 31 * result + (apartment != null ? apartment.hashCode() : 0);
        return result;
    }
}
